==> projen-0.45.3-sources.jar: io/github/cdklabs/projen/InitProject.java <==
package io.github.cdklabs.projen;

/**
 * (experimental) Information passed from `projen new` to the project object when the project is first created.
 * <p>
 * It is used to generate projenrc files in various languages.
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.47.0 (build 86d2c33)", date = "2021-12-20T00:39:28.409Z")
@software.amazon.jsii.Jsii(module = io.github.cdklabs.projen.$Module.class, fqn = "projen.InitProject")
@software.amazon.jsii.Jsii.Proxy(InitProject.Jsii$Proxy.class)
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
public interface InitProject extends software.amazon.jsii.JsiiSerializable {

    /**
     * (experimental) Initial arguments passed to `projen new`.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    @org.jetbrains.annotations.NotNull java.util.Map<java.lang.String, java.lang.Object> getArgs();

    /**
     * (experimental) Include commented out options.
     * <p>
     * Does not apply to projenrc.json files.
     * <p>
     * Default: InitProjectOptionHints.FEATURED
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    @org.jetbrains.annotations.NotNull io.github.cdklabs.projen.InitProjectOptionHints getComments();

    /**
     * (experimental) The JSII FQN of the project type.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    @org.jetbrains.annotations.NotNull java.lang.String getFqn();

    /**
     * (experimental) Project metadata.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    @org.jetbrains.annotations.NotNull io.github.cdklabs.projen.ProjectType getType();

    /**
     * @return a {@link Builder} of {@link InitProject}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    static Builder builder() {
        return new Builder();
    }
    /**
     * A builder for {@link InitProject}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public static final class Builder implements software.amazon.jsii.Builder<InitProject> {
        java.util.Map<java.lang.String, java.lang.Object> args;
        io.github.cdklabs.projen.InitProjectOptionHints comments;
        java.lang.String fqn;
        io.github.cdklabs.projen.ProjectType type;

        /**
         * Sets the value of {@link InitProject#getArgs}
         * @param args Initial arguments passed to `projen new`. This parameter is required.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        @SuppressWarnings("unchecked")
        public Builder args(java.util.Map<java.lang.String, ? extends java.lang.Object> args) {
            this.args = (java.util.Map<java.lang.String, java.lang.Object>)args;
            return this;
        }

        /**
         * Sets the value of {@link InitProject#getComments}
         * @param comments Include commented out options. This parameter is required.
         *                 Does not apply to projenrc.json files.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder comments(io.github.cdklabs.projen.InitProjectOptionHints comments) {
            this.comments = comments;
            return this;
        }

        /**
         * Sets the value of {@link InitProject#getFqn}
         * @param fqn The JSII FQN of the project type. This parameter is required.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder fqn(java.lang.String fqn) {
            this.fqn = fqn;
            return this;
        }

        /**
         * Sets the value of {@link InitProject#getType}
         * @param type Project metadata. This parameter is required.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder type(io.github.cdklabs.projen.ProjectType type) {
            this.type = type;
            return this;
        }

        /**
         * Builds the configured instance.
         * @return a new instance of {@link InitProject}
         * @throws NullPointerException if any required attribute was not provided
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        @Override
        public InitProject build() {
            return new Jsii$Proxy(this);
        }
    }

    /**
     * An implementation for {@link InitProject}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    @software.amazon.jsii.Internal
    final class Jsii$Proxy extends software.amazon.jsii.JsiiObject implements InitProject {
        private final java.util.Map<java.lang.String, java.lang.Object> args;
        private final io.github.cdklabs.projen.InitProjectOptionHints comments;
        private final java.lang.String fqn;
        private final io.github.cdklabs.projen.ProjectType type;

        /**
         * Constructor that initializes the object based on values retrieved from the JsiiObject.
         * @param objRef Reference to the JSII managed object.
         */
        protected Jsii$Proxy(final software.amazon.jsii.JsiiObjectRef objRef) {
            super(objRef);
            this.args = software.amazon.jsii.Kernel.get(this, "args", software.amazon.jsii.NativeType.mapOf(software.amazon.jsii.NativeType.forClass(java.lang.Object.class)));
            this.comments = software.amazon.jsii.Kernel.get(this, "comments", software.amazon.jsii.NativeType.forClass(io.github.cdklabs.projen.InitProjectOptionHints.class));
            this.fqn = software.amazon.jsii.Kernel.get(this, "fqn", software.amazon.jsii.NativeType.forClass(java.lang.String.class));
            this.type = software.amazon.jsii.Kernel.get(this, "type", software.amazon.jsii.NativeType.forClass(io.github.cdklabs.projen.ProjectType.class));
        }

        /**
         * Constructor that initializes the object based on literal property values passed by the {@link Builder}.
         */
        @SuppressWarnings("unchecked")
        protected Jsii$Proxy(final Builder builder) {
            super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
            this.args = (java.util.Map<java.lang.String, java.lang.Object>)java.util.Objects.requireNonNull(builder.args, "args is required");
            this.comments = java.util.Objects.requireNonNull(builder.comments, "comments is required");
            this.fqn = java.util.Objects.requireNonNull(builder.fqn, "fqn is required");
            this.type = java.util.Objects.requireNonNull(builder.type, "type is required");
        }

        @Override
        public final java.util.Map<java.lang.String, java.lang.Object> getArgs() {
            return this.args;
        }

        @Override
        public final io.github.cdklabs.projen.InitProjectOptionHints getComments() {
            return this.comments;
        }

        @Override
        public final java.lang.String getFqn() {
            return this.fqn;
        }

        @Override
        public final io.github.cdklabs.projen.ProjectType getType() {
            return this.type;
        }

        @Override
        @software.amazon.jsii.Internal
        public com.fasterxml.jackson.databind.JsonNode $jsii$toJson() {
            final com.fasterxml.jackson.databind.ObjectMapper om = software.amazon.jsii.JsiiObjectMapper.INSTANCE;
            final com.fasterxml.jackson.databind.node.ObjectNode data = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();

            data.set("args", om.valueToTree(this.getArgs()));
            data.set("comments", om.valueToTree(this.getComments()));
            data.set("fqn", om.valueToTree(this.getFqn()));
            data.set("type", om.valueToTree(this.getType()));

            final com.fasterxml.jackson.databind.node.ObjectNode struct = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            struct.set("fqn", om.valueToTree("projen.InitProject"));
            struct.set("data", data);

            final com.fasterxml.jackson.databind.node.ObjectNode obj = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            obj.set("$jsii.struct", struct);

            return obj;
        }

        @Override
        public final boolean equals(final Object o) {
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;

            InitProject.Jsii$Proxy that = (InitProject.Jsii$Proxy) o;

            if (!args.equals(that.args)) return false;
            if (!comments.equals(that.comments)) return false;
            if (!fqn.equals(that.fqn)) return false;
            return this.type.equals(that.type);
        }

        @Override
        public final int hashCode() {
            int result = this.args.hashCode();
            result = 31 * result + (this.comments.hashCode());
            result = 31 * result + (this.fqn.hashCode());
            result = 31 * result + (this.type.hashCode());
            return result;
        }
    }
}

==> projen-0.79.0-sources.jar: io/github/cdklabs/projen/InitProject.java <==
package io.github.cdklabs.projen;

/**
 * (experimental) Information passed from <code>projen new</code> to the project object when the project is first created.
 * <p>
 * It is used to generate projenrc files in various languages.
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.94.0 (build b380f01)", date = "2024-01-10T23:18:45.112Z")
@software.amazon.jsii.Jsii(module = io.github.cdklabs.projen.$Module.class, fqn = "projen.InitProject")
@software.amazon.jsii.Jsii.Proxy(InitProject.Jsii$Proxy.class)
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
public interface InitProject extends software.amazon.jsii.JsiiSerializable {

    /**
     * (experimental) Initial arguments passed to <code>projen new</code>.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    @org.jetbrains.annotations.NotNull java.util.Map<java.lang.String, java.lang.Object> getArgs();

    /**
     * (experimental) Include commented out options.
     * <p>
     * Does not apply to projenrc.json files.
     * <p>
     * Default: InitProjectOptionHints.FEATURED
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    @org.jetbrains.annotations.NotNull io.github.cdklabs.projen.InitProjectOptionHints getComments();

    /**
     * (experimental) The JSII FQN of the project type.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    @org.jetbrains.annotations.NotNull java.lang.String getFqn();

    /**
     * (experimental) Project metadata.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    @org.jetbrains.annotations.NotNull io.github.cdklabs.projen.ProjectType getType();

    /**
     * @return a {@link Builder} of {@link InitProject}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    static Builder builder() {
        return new Builder();
    }
    /**
     * A builder for {@link InitProject}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public static final class Builder implements software.amazon.jsii.Builder<InitProject> {
        java.util.Map<java.lang.String, java.lang.Object> args;
        io.github.cdklabs.projen.InitProjectOptionHints comments;
        java.lang.String fqn;
        io.github.cdklabs.projen.ProjectType type;

        /**
         * Sets the value of {@link InitProject#getArgs}
         * @param args Initial arguments passed to <code>projen new</code>. This parameter is required.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        @SuppressWarnings("unchecked")
        public Builder args(java.util.Map<java.lang.String, ? extends java.lang.Object> args) {
            this.args = (java.util.Map<java.lang.String, java.lang.Object>)args;
            return this;
        }

        /**
         * Sets the value of {@link InitProject#getComments}
         * @param comments Include commented out options. This parameter is required.
         *                 Does not apply to projenrc.json files.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder comments(io.github.cdklabs.projen.InitProjectOptionHints comments) {
            this.comments = comments;
            return this;
        }

        /**
         * Sets the value of {@link InitProject#getFqn}
         * @param fqn The JSII FQN of the project type. This parameter is required.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder fqn(java.lang.String fqn) {
            this.fqn = fqn;
            return this;
        }

        /**
         * Sets the value of {@link InitProject#getType}
         * @param type Project metadata. This parameter is required.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder type(io.github.cdklabs.projen.ProjectType type) {
            this.type = type;
            return this;
        }

        /**
         * Builds the configured instance.
         * @return a new instance of {@link InitProject}
         * @throws NullPointerException if any required attribute was not provided
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        @Override
        public InitProject build() {
            return new Jsii$Proxy(this);
        }
    }

    /**
     * An implementation for {@link InitProject}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    @software.amazon.jsii.Internal
    final class Jsii$Proxy extends software.amazon.jsii.JsiiObject implements InitProject {
        private final java.util.Map<java.lang.String, java.lang.Object> args;
        private final io.github.cdklabs.projen.InitProjectOptionHints comments;
        private final java.lang.String fqn;
        private final io.github.cdklabs.projen.ProjectType type;

        /**
         * Constructor that initializes the object based on values retrieved from the JsiiObject.
         * @param objRef Reference to the JSII managed object.
         */
        protected Jsii$Proxy(final software.amazon.jsii.JsiiObjectRef objRef) {
            super(objRef);
            this.args = software.amazon.jsii.Kernel.get(this, "args", software.amazon.jsii.NativeType.mapOf(software.amazon.jsii.NativeType.forClass(java.lang.Object.class)));
            this.comments = software.amazon.jsii.Kernel.get(this, "comments", software.amazon.jsii.NativeType.forClass(io.github.cdklabs.projen.InitProjectOptionHints.class));
            this.fqn = software.amazon.jsii.Kernel.get(this, "fqn", software.amazon.jsii.NativeType.forClass(java.lang.String.class));
            this.type = software.amazon.jsii.Kernel.get(this, "type", software.amazon.jsii.NativeType.forClass(io.github.cdklabs.projen.ProjectType.class));
        }

        /**
         * Constructor that initializes the object based on literal property values passed by the {@link Builder}.
         */
        @SuppressWarnings("unchecked")
        protected Jsii$Proxy(final Builder builder) {
            super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
            this.args = (java.util.Map<java.lang.String, java.lang.Object>)java.util.Objects.requireNonNull(builder.args, "args is required");
            this.comments = java.util.Objects.requireNonNull(builder.comments, "comments is required");
            this.fqn = java.util.Objects.requireNonNull(builder.fqn, "fqn is required");
            this.type = java.util.Objects.requireNonNull(builder.type, "type is required");
        }

        @Override
        public final java.util.Map<java.lang.String, java.lang.Object> getArgs() {
            return this.args;
        }

        @Override
        public final io.github.cdklabs.projen.InitProjectOptionHints getComments() {
            return this.comments;
        }

        @Override
        public final java.lang.String getFqn() {
            return this.fqn;
        }

        @Override
        public final io.github.cdklabs.projen.ProjectType getType() {
            return this.type;
        }

        @Override
        @software.amazon.jsii.Internal
        public com.fasterxml.jackson.databind.JsonNode $jsii$toJson() {
            final com.fasterxml.jackson.databind.ObjectMapper om = software.amazon.jsii.JsiiObjectMapper.INSTANCE;
            final com.fasterxml.jackson.databind.node.ObjectNode data = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();

            data.set("args", om.valueToTree(this.getArgs()));
            data.set("comments", om.valueToTree(this.getComments()));
            data.set("fqn", om.valueToTree(this.getFqn()));
            data.set("type", om.valueToTree(this.getType()));

            final com.fasterxml.jackson.databind.node.ObjectNode struct = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            struct.set("fqn", om.valueToTree("projen.InitProject"));
            struct.set("data", data);

            final com.fasterxml.jackson.databind.node.ObjectNode obj = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            obj.set("$jsii.struct", struct);

            return obj;
        }

        @Override
        public final boolean equals(final Object o) {
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;

            InitProject.Jsii$Proxy that = (InitProject.Jsii$Proxy) o;

            if (!args.equals(that.args)) return false;
            if (!comments.equals(that.comments)) return false;
            if (!fqn.equals(that.fqn)) return false;
            return this.type.equals(that.type);
        }

        @Override
        public final int hashCode() {
            int result = this.args.hashCode();
            result = 31 * result + (this.comments.hashCode());
            result = 31 * result + (this.fqn.hashCode());
            result = 31 * result + (this.type.hashCode());
            return result;
        }
    }
}
